# SPDX-License-Identifier: CC0-1.0

{ pkgs, ... }:
with pkgs;

let
  solo5Test = { name, machine, ... }@args:
    args // {
      name = "solo5-" + name;
      machine = machine // {
        inputs = [ pkgs.solo5 pkgs.solo5.tests ] ++ machine.inputs;
      };
    };

  genodeDepot = pkgs.genodeSources.depot;
  genodeMake = pkgs.genodeSources.make;

in map solo5Test [
  {
    name = "multi";
    machine = {
      config = "${./.}/solo5.dhall { isAarch64 = ${
          if pkgs.stdenv.hostPlatform.isAarch64 then "True" else "False"
        } }";
      inputs = map genodeMake [ "app/ping" ] ++ (map genodeDepot [
        "ram_block"
        "nic_bridge"
        "nic_loopback"
        "sequence"
      ]);
    };
  }

  {
    name = "ssp";
    machine = {
      config = ./ssp.dhall;
      inputs = [ ];
    };
    testScript = ''
      start_all()
      machine.wait_until_serial_output("Error: stack protector check failed")
    '';
  }

]
